summaryrefslogtreecommitdiff
path: root/resources/jquery/jquery.cookie.js
diff options
context:
space:
mode:
Diffstat (limited to 'resources/jquery/jquery.cookie.js')
-rw-r--r--resources/jquery/jquery.cookie.js87
1 files changed, 47 insertions, 40 deletions
diff --git a/resources/jquery/jquery.cookie.js b/resources/jquery/jquery.cookie.js
index eaa254e5..79317f74 100644
--- a/resources/jquery/jquery.cookie.js
+++ b/resources/jquery/jquery.cookie.js
@@ -1,19 +1,15 @@
-/*jslint browser: true */ /*global jQuery: true */
-
/**
- * jQuery Cookie plugin
+ * Cookie plugin
*
- * Copyright (c) 2010 Klaus Hartl (stilbuero.de)
+ * Copyright (c) 2006 Klaus Hartl (stilbuero.de)
* Dual licensed under the MIT and GPL licenses:
* http://www.opensource.org/licenses/mit-license.php
* http://www.gnu.org/licenses/gpl.html
*
*/
-// TODO JsDoc
-
/**
* Create a cookie with the given key and value and other optional parameters.
*
* @example $.cookie('the_cookie', 'the_value');
* @desc Set the value of a cookie.
@@ -25,16 +21,16 @@
* @desc Delete a cookie by passing null as value. Keep in mind that you have to use the same path and domain
* used when the cookie was set.
*
* @param key String The key of the cookie.
* @param value String The value of the cookie.
* @param options Object An object literal containing key/value pairs to provide optional cookie attributes.
* @option expires Number|Date Either an integer specifying the expiration date from now on in days or a Date object.
* If a negative value is specified (e.g. a date in the past), the cookie will be deleted.
* If set to null or omitted, the cookie will be a session cookie and will not be retained
* when the the browser exits.
- * @option path String The value of the path atribute of the cookie (default: path of page that created the cookie).
- * @option domain String The value of the domain attribute of the cookie (default: domain of page that created the cookie).
- * @option secure Boolean If true, the secure attribute of the cookie will be set and the cookie transmission will
+ * @option String path The value of the path atribute of the cookie (default: path of page that created the cookie).
+ * @option String domain The value of the domain attribute of the cookie (default: domain of page that created the cookie).
+ * @option Boolean secure If true, the secure attribute of the cookie will be set and the cookie transmission will
* require a secure protocol (like HTTPS).
* @type undefined
*
@@ -44,12 +40,12 @@
*/
/**
* Get the value of a cookie with the given key.
*
* @example $.cookie('the_cookie');
* @desc Get the value of a cookie.
*
* @param key String The key of the cookie.
* @return The value of the cookie.
* @type String
*
@@ -57,33 +53,44 @@
* @cat Plugins/Cookie
* @author Klaus Hartl/klaus.hartl@stilbuero.de
*/
-jQuery.cookie = function (key, value, options) {
-
- // key and value given, set cookie...
- if (arguments.length > 1 && (value === null || typeof value !== "object")) {
- options = jQuery.extend({}, options);
-
+jQuery.cookie = function(name, value, options) {
+ if (typeof value != 'undefined') { // name and value given, set cookie
+ options = options || {};
if (value === null) {
+ value = '';
options.expires = -1;
}
-
- if (typeof options.expires === 'number') {
- var days = options.expires, t = options.expires = new Date();
- t.setDate(t.getDate() + days);
+ var expires = '';
+ if (options.expires && (typeof options.expires == 'number' || options.expires.toUTCString)) {
+ var date;
+ if (typeof options.expires == 'number') {
+ date = new Date();
+ date.setTime(date.getTime() + (options.expires * 24 * 60 * 60 * 1000));
+ } else {
+ date = options.expires;
+ }
+ expires = '; expires=' + date.toUTCString(); // use expires attribute, max-age is not supported by IE
}
-
- return (document.cookie = [
- encodeURIComponent(key), '=',
- options.raw ? String(value) : encodeURIComponent(String(value)),
- options.expires ? '; expires=' + options.expires.toUTCString() : '', // use expires attribute, max-age is not supported by IE
- options.path ? '; path=' + options.path : '',
- options.domain ? '; domain=' + options.domain : '',
- options.secure ? '; secure' : ''
- ].join(''));
+ // CAUTION: Needed to parenthesize options.path and options.domain
+ // in the following expressions, otherwise they evaluate to undefined
+ // in the packed version for some reason...
+ var path = options.path ? '; path=' + (options.path) : '';
+ var domain = options.domain ? '; domain=' + (options.domain) : '';
+ var secure = options.secure ? '; secure' : '';
+ document.cookie = [name, '=', encodeURIComponent(value), expires, path, domain, secure].join('');
+ } else { // only name given, get cookie
+ var cookieValue = null;
+ if (document.cookie && document.cookie != '') {
+ var cookies = document.cookie.split(';');
+ for (var i = 0; i < cookies.length; i++) {
+ var cookie = jQuery.trim(cookies[i]);
+ // Does this cookie string begin with the name we want?
+ if (cookie.substring(0, name.length + 1) == (name + '=')) {
+ cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
+ break;
+ }
+ }
+ }
+ return cookieValue;
}
-
- // key and possibly options given, get cookie...
- options = value || {};
- var result, decode = options.raw ? function (s) { return s; } : decodeURIComponent;
- return (result = new RegExp('(?:^|; )' + encodeURIComponent(key) + '=([^;]*)').exec(document.cookie)) ? decode(result[1]) : null;
};
@@ -1,19 +1,15 @@
/**
- * Create a cookie with the given key and value and other optional parameters.
+ * Create a cookie with the given name and value and other optional parameters.
*
* @example $.cookie('the_cookie', 'the_value');
@@ -25,16 +21,16 @@
* used when the cookie was set.
*
- * @param key String The key of the cookie.
- * @param value String The value of the cookie.
- * @param options Object An object literal containing key/value pairs to provide optional cookie attributes.
- * @option expires Number|Date Either an integer specifying the expiration date from now on in days or a Date object.
+ * @param String name The name of the cookie.
+ * @param String value The value of the cookie.
+ * @param Object options An object literal containing key/value pairs to provide optional cookie attributes.
+ * @option Number|Date expires Either an integer specifying the expiration date from now on in days or a Date object.
* If a negative value is specified (e.g. a date in the past), the cookie will be deleted.
* If set to null or omitted, the cookie will be a session cookie and will not be retained
@@ -44,12 +40,12 @@
*/
/**
- * Get the value of a cookie with the given key.
+ * Get the value of a cookie with the given name.
*
* @example $.cookie('the_cookie');
@@ -44,12 +40,12 @@
* @desc Get the value of a cookie.
*
- * @param key String The key of the cookie.
+ * @param String name The name of the cookie.
* @return The value of the cookie.
* @type String